library(plyr)
library(rstan)
library(polspline)

# Bayes factors for ellipsis site + 1 in Experiment 2 (English data)

fit <- function(pars){
	dat_p1 <- list(subject=as.integer(factor(p1$subj)),
               item=as.integer(factor(p1$item)),
               x=p1$rrt, ## dep. var.        
               grp = p1$grp,
               comp = p1$comp,
               prior_sd = pars[1]/2,
               lo = pars[2],
               up = pars[3],
               N = nrow(p1),
               I = length(unique(p1$subj)),
               K = length(unique(p1$item)))

params<-c("inter","beta_1","beta_2","beta_3","sigma_e","sigma_u","sigma_w")

bf_mod1 <- stan(file="bfs2.stan",
				control=list(adapt_delta=.99),
                iter=4000,
                chains=4,
                cores=4,
                warmup=2000,
                data=dat_p1,
                pars=params,
                refresh=-1)

name <- paste("bf2_",pars[1],"-",pars[2],"-",pars[3],".Rda")
save(bf_mod1,file=name)
print(bf_mod1,probs = c(0.025,0.975),digits_summary=4)

samples <- data.frame(extract(bf_mod1)) # It saves all the samples from the model.
post <- samples$beta_3

if (pars[2] == 0) {fit_posterior <- logspline(post,lbound=0)} else if (pars[3] == 0) {fit_posterior <- logspline(post,ubound=0)}
#summary(fit_posterior)
posterior <- dlogspline(0, fit_posterior) # Height of the posterior at 0
prior <- dnorm(0, 0, pars[1]/2)
return(posterior/prior)
}

data2 <- read.table("b1data")
data3 <- read.table("b2data")
data2$V1 <- paste(data2$V1, "-b1")
data3$V1 <- paste(data3$V1, "-b2")
data2$V2 <- paste(data2$V2, "-b1")
data3$V2 <- paste(data3$V2, "-b2")
bdata <- rbind(data2,data3)
colnames(bdata) <- c("subj","exp","item","condition","pos","word","roi","rt")
bdata$rrt <- -1000/bdata$rt

# ENGLISH ONLY

bdata$subj <- as.numeric(as.character(substr(bdata$subj,1,2)))
bdata$subj <- bdata$subj*100
bdata$subj <- ifelse(bdata$exp=="el -b2",bdata$subj+20000,bdata$subj+10000)
bdata <- subset(bdata, roi != 1 & roi != 0 & exp%in%c("el -b1","el -b2"))
bdata$comp <- ifelse(bdata$condition=="a",-1,1)
bdata$grp <- ifelse(bdata$exp=="el -b1",-1,1)
p1 <- subset(bdata, roi%in%c("el+1")) 

(f1 <- fit(c(0.1,0,Inf)))
(f2 <- fit(c(0.05,0,Inf)))
(f3 <- fit(c(0.01,0,Inf)))
(f4 <- fit(c(0.1,-Inf,0)))
(f5 <- fit(c(0.05,-Inf,0)))
(f6 <- fit(c(0.01,-Inf,0)))
