data {
	int<lower=1> N;
	real lo;
	real up;
	real x[N];
	real<lower=-1,upper=1> el[N];  //predictors
	real<lower=-1,upper=1> comp[N]; 
	real prior_sd;
	int<lower=1> I;                  //number of subjects
	int<lower=1> K;                  //number of items
	int<lower=1, upper=I> subject[N];   //subject id
	int<lower=1, upper=K> item[N];   //item id
}

parameters {
	real inter;
	real<lower=lo,upper=up> beta_1;
	real beta_2;
	real beta_3;
	real<lower=0> sigma_e;			// residual sd
	vector<lower=0>[4] sigma_u;	// subj sd
	vector<lower=0>[4] sigma_w;	// item sd
	cholesky_factor_corr[4] L_u;
	cholesky_factor_corr[4] L_w;
	matrix[4,I] z_u;
	matrix[4,K] z_w;
}

model {
	matrix[I,4] u;	// random intercept and slopes subj
	matrix[K,4] w;  // random intercept and slopes item
	
	# priors:
	inter ~ normal(0,10);
	beta_2 ~ normal(0,1);
	beta_3 ~ normal(0,1);
	# beta_1 ~ normal(0,1);
	beta_1 ~ normal(0,prior_sd);
	sigma_e ~ normal(0,1);
	sigma_u ~ normal(0,1);
	sigma_w ~ normal(0,1);
	L_u ~ lkj_corr_cholesky(1.0);
	L_w ~ lkj_corr_cholesky(1.0);
	to_vector(z_u) ~ normal(0,1);
	to_vector(z_w) ~ normal(0,1);
	
	u = (diag_pre_multiply(sigma_u,L_u) * z_u)';	// subj random effects
	w = (diag_pre_multiply(sigma_w,L_w) * z_w)';	// item random effects
	
	for (n in 1:N){
		real mu_ellipsis;

		mu_ellipsis = inter + u[subject[n],1]+w[item[n],1]+
		(beta_1+u[subject[n],2]+ w[item[n],2])*comp[n]+
		(beta_2+u[subject[n],3]+ w[item[n],3])*el[n]+
		(beta_3+u[subject[n],4]+ w[item[n],4])*comp[n]*el[n];
		x[n] ~ normal(mu_ellipsis,sigma_e);
        } 

}
